Enum Skill

pub enum Skill {
Show 136 variants None, Frost, Fire, Arms, Combat, Subtlety, Poisons, Swords, Axes, Bows, Guns, BeastMastery, Survival, Maces, TwoHandedSwords, Holy, Shadow, Defense, LanguageCommon, RacialDwarven, LanguageOrcish, LanguageDwarven, LanguageDarnassian, LanguageTaurahe, DualWield, RacialTauren, OrcRacial, RacialNightElf, FirstAid, FeralCombat, Staves, LanguageThalassian, LanguageDraconic, LanguageDemonTongue, LanguageTitan, LanguageOldTongue, Survival2, RidingHorse, RidingWolf, RidingTiger, RidingRam, Swimming, TwoHandedMaces, Unarmed, Marksmanship, Blacksmithing, Leatherworking, Alchemy, TwoHandedAxes, Daggers, Thrown, Herbalism, GenericDnd, Retribution, Cooking, Mining, PetImp, PetFelhunter, Tailoring, Engineering, PetSpider, PetVoidwalker, PetSuccubus, PetInfernal, PetDoomguard, PetWolf, PetCat, PetBear, PetBoar, PetCrocilisk, PetCarrionBird, PetCrab, PetGorilla, PetRaptor, PetTallstrider, RacialUnded, Crossbows, Wands, Polearms, PetScorpid, Arcane, PetTurtle, Assassination, Fury, Protection, BeastTraining, Protection2, PetTalents, PlateMail, LanguageGnomish, LanguageTroll, Enchanting, Demonology, Affliction, Fishing, Enhancement, Restoration, ElementalCombat, Skinning, Mail, Leather, Cloth, Shield, FistWeapons, RidingRaptor, RidingMechanostrider, RidingUndeadHorse, Restoration2, Balance, Destruction, Holy2, Discipline, Lockpicking, PetBat, PetHyena, PetOwl, PetWindSerpent, LanguageGutterspeak, RidingKodo, RacialTroll, RacialGnome, RacialHuman, Jewelcrafting, RacialBloodelf, PetEventRc, LanguageDraenei, RacialDraenei, PetFelguard, Riding, PetDragonhawk, PetNetherRay, PetSporebat, PetWarpStalker, PetRavager, PetSerpent, Internal,
}
Available on crate feature tbc only.
Auto generated from the original wowm in file wow_message_parser/wowm/world/enums/skill.wowm:131:

enum Skill : u16 {
    NONE = 0;
    FROST = 6;
    FIRE = 8;
    ARMS = 26;
    COMBAT = 38;
    SUBTLETY = 39;
    POISONS = 40;
    SWORDS = 43;
    AXES = 44;
    BOWS = 45;
    GUNS = 46;
    BEAST_MASTERY = 50;
    SURVIVAL = 51;
    MACES = 54;
    TWO_HANDED_SWORDS = 55;
    HOLY = 56;
    SHADOW = 78;
    DEFENSE = 95;
    LANGUAGE_COMMON = 98;
    RACIAL_DWARVEN = 101;
    LANGUAGE_ORCISH = 109;
    LANGUAGE_DWARVEN = 111;
    LANGUAGE_DARNASSIAN = 113;
    LANGUAGE_TAURAHE = 115;
    DUAL_WIELD = 118;
    RACIAL_TAUREN = 124;
    ORC_RACIAL = 125;
    RACIAL_NIGHT_ELF = 126;
    FIRST_AID = 129;
    FERAL_COMBAT = 134;
    STAVES = 136;
    LANGUAGE_THALASSIAN = 137;
    LANGUAGE_DRACONIC = 138;
    LANGUAGE_DEMON_TONGUE = 139;
    LANGUAGE_TITAN = 140;
    LANGUAGE_OLD_TONGUE = 141;
    SURVIVAL2 = 142;
    RIDING_HORSE = 148;
    RIDING_WOLF = 149;
    RIDING_TIGER = 150;
    RIDING_RAM = 152;
    SWIMMING = 155;
    TWO_HANDED_MACES = 160;
    UNARMED = 162;
    MARKSMANSHIP = 163;
    BLACKSMITHING = 164;
    LEATHERWORKING = 165;
    ALCHEMY = 171;
    TWO_HANDED_AXES = 172;
    DAGGERS = 173;
    THROWN = 176;
    HERBALISM = 182;
    GENERIC_DND = 183;
    RETRIBUTION = 184;
    COOKING = 185;
    MINING = 186;
    PET_IMP = 188;
    PET_FELHUNTER = 189;
    TAILORING = 197;
    ENGINEERING = 202;
    PET_SPIDER = 203;
    PET_VOIDWALKER = 204;
    PET_SUCCUBUS = 205;
    PET_INFERNAL = 206;
    PET_DOOMGUARD = 207;
    PET_WOLF = 208;
    PET_CAT = 209;
    PET_BEAR = 210;
    PET_BOAR = 211;
    PET_CROCILISK = 212;
    PET_CARRION_BIRD = 213;
    PET_CRAB = 214;
    PET_GORILLA = 215;
    PET_RAPTOR = 217;
    PET_TALLSTRIDER = 218;
    RACIAL_UNDED = 220;
    CROSSBOWS = 226;
    WANDS = 228;
    POLEARMS = 229;
    PET_SCORPID = 236;
    ARCANE = 237;
    PET_TURTLE = 251;
    ASSASSINATION = 253;
    FURY = 256;
    PROTECTION = 257;
    BEAST_TRAINING = 261;
    PROTECTION2 = 267;
    PET_TALENTS = 270;
    PLATE_MAIL = 293;
    LANGUAGE_GNOMISH = 313;
    LANGUAGE_TROLL = 315;
    ENCHANTING = 333;
    DEMONOLOGY = 354;
    AFFLICTION = 355;
    FISHING = 356;
    ENHANCEMENT = 373;
    RESTORATION = 374;
    ELEMENTAL_COMBAT = 375;
    SKINNING = 393;
    MAIL = 413;
    LEATHER = 414;
    CLOTH = 415;
    SHIELD = 433;
    FIST_WEAPONS = 473;
    RIDING_RAPTOR = 533;
    RIDING_MECHANOSTRIDER = 553;
    RIDING_UNDEAD_HORSE = 554;
    RESTORATION2 = 573;
    BALANCE = 574;
    DESTRUCTION = 593;
    HOLY2 = 594;
    DISCIPLINE = 613;
    LOCKPICKING = 633;
    PET_BAT = 653;
    PET_HYENA = 654;
    PET_OWL = 655;
    PET_WIND_SERPENT = 656;
    LANGUAGE_GUTTERSPEAK = 673;
    RIDING_KODO = 713;
    RACIAL_TROLL = 733;
    RACIAL_GNOME = 753;
    RACIAL_HUMAN = 754;
    JEWELCRAFTING = 755;
    RACIAL_BLOODELF = 756;
    PET_EVENT_RC = 758;
    LANGUAGE_DRAENEI = 759;
    RACIAL_DRAENEI = 760;
    PET_FELGUARD = 761;
    RIDING = 762;
    PET_DRAGONHAWK = 763;
    PET_NETHER_RAY = 764;
    PET_SPOREBAT = 765;
    PET_WARP_STALKER = 766;
    PET_RAVAGER = 767;
    PET_SERPENT = 768;
    INTERNAL = 769;
}

Variants



None



Frost



Fire



Arms



Combat



Subtlety



Poisons



Swords



Axes



Bows



Guns



BeastMastery



Survival



Maces



TwoHandedSwords



Holy



Shadow



Defense



LanguageCommon



RacialDwarven



LanguageOrcish



LanguageDwarven



LanguageDarnassian



LanguageTaurahe



DualWield



RacialTauren



OrcRacial



RacialNightElf



FirstAid



FeralCombat



Staves



LanguageThalassian



LanguageDraconic



LanguageDemonTongue



LanguageTitan



LanguageOldTongue



Survival2



RidingHorse



RidingWolf



RidingTiger



RidingRam



Swimming



TwoHandedMaces



Unarmed



Marksmanship



Blacksmithing



Leatherworking



Alchemy



TwoHandedAxes



Daggers



Thrown



Herbalism



GenericDnd



Retribution



Cooking



Mining



PetImp



PetFelhunter



Tailoring



Engineering



PetSpider



PetVoidwalker



PetSuccubus



PetInfernal



PetDoomguard



PetWolf



PetCat



PetBear



PetBoar



PetCrocilisk



PetCarrionBird



PetCrab



PetGorilla



PetRaptor



PetTallstrider



RacialUnded



Crossbows



Wands



Polearms



PetScorpid



Arcane



PetTurtle



Assassination



Fury



Protection



BeastTraining



Protection2



PetTalents



PlateMail



LanguageGnomish



LanguageTroll



Enchanting



Demonology



Affliction



Fishing



Enhancement



Restoration



ElementalCombat



Skinning



Mail



Leather



Cloth



Shield



FistWeapons



RidingRaptor



RidingMechanostrider



RidingUndeadHorse



Restoration2



Balance



Destruction



Holy2



Discipline



Lockpicking



PetBat



PetHyena



PetOwl



PetWindSerpent



LanguageGutterspeak



RidingKodo



RacialTroll



RacialGnome



RacialHuman



Jewelcrafting



RacialBloodelf



PetEventRc



LanguageDraenei



RacialDraenei



PetFelguard



Riding



PetDragonhawk



PetNetherRay



PetSporebat



PetWarpStalker



PetRavager



PetSerpent



Internal

Implementations

Source

impl Skill

pub const fn category(&self) -> Option<SkillCategory>

Available on crate feature extended only.
Source

impl Skill

pub const fn as_int(&self) -> u16

pub const fn variants() -> [Self; 136]

pub const fn from_int(value: u16) -> Result<Self, EnumError>

Source

impl Skill

pub const fn as_test_case_value(&self) -> &'static str

Available on crate feature print-testcase only.