pub enum StatusId {
None,
WaitQueue,
WaitJoin,
InProgress,
WaitLeave,
}Available on crate feature
tbc and (crate features shared or vanilla or tbc or wrath) only.Expand description
Auto generated from the original wowm in file wow_message_parser/wowm/world/battleground/smsg_battlefield_status.wowm:1:
enum StatusId : u8 {
NONE = 0;
WAIT_QUEUE = 1;
WAIT_JOIN = 2;
IN_PROGRESS = 3;
WAIT_LEAVE = 4;
}Variants
None
first status, should mean bg is not instance
WaitQueue
means bg is empty and waiting for queue
WaitJoin
this means, that BG has already started and it is waiting for more players
InProgress
means bg is running
WaitLeave
means some faction has won BG and it is ending
Implementations