pub enum LootMethod {
ErrorX,
Corpse,
Pickpocketing,
Fishing,
Disenchanting,
Skinning,
Fishinghole,
FishingFail,
Insignia,
}Available on crate feature
vanilla and (crate features shared or vanilla or tbc or wrath) only.Expand description
Auto generated from the original wowm in file wow_message_parser/wowm/world/loot/smsg_loot_response.wowm:1:
enum LootMethod : u8 {
ERROR = 0;
CORPSE = 1;
PICKPOCKETING = 2;
FISHING = 3;
DISENCHANTING = 4;
SKINNING = 6;
FISHINGHOLE = 20;
FISHING_FAIL = 21;
INSIGNIA = 22;
}Variants
ErrorX
Corpse
Pickpocketing
Fishing
Disenchanting
Skinning
unsupported by client, send LOOT_PICKPOCKETING instead
Fishinghole
unsupported by client, send LOOT_FISHING instead
FishingFail
unsupported by client, send LOOT_FISHING instead
Insignia
unsupported by client, send LOOT_CORPSE instead
Implementations
Sourceimpl LootMethod
impl LootMethod
Sourceimpl LootMethod
impl LootMethod
pub const fn as_test_case_value(&self) -> &'static str
Available on crate feature
print-testcase only.Trait Implementations
Sourceimpl Clone for LootMethod
impl Clone for LootMethod
Sourcefn clone(&self) -> LootMethod
fn clone(&self) -> LootMethod
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LootMethod
impl Debug for LootMethod
Sourceimpl Default for LootMethod
impl Default for LootMethod
Sourceimpl<'de> Deserialize<'de> for LootMethod
impl<'de> Deserialize<'de> for LootMethod
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for LootMethod
impl Display for LootMethod
Sourceimpl Hash for LootMethod
impl Hash for LootMethod
Sourceimpl Ord for LootMethod
impl Ord for LootMethod
Sourcefn cmp(&self, other: &LootMethod) -> Ordering
fn cmp(&self, other: &LootMethod) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LootMethod
impl PartialEq for LootMethod
Sourceimpl PartialOrd for LootMethod
impl PartialOrd for LootMethod
Sourceimpl Serialize for LootMethod
impl Serialize for LootMethod
Sourceimpl TryFrom<i16> for LootMethod
impl TryFrom<i16> for LootMethod
Sourceimpl TryFrom<i32> for LootMethod
impl TryFrom<i32> for LootMethod
Sourceimpl TryFrom<i64> for LootMethod
impl TryFrom<i64> for LootMethod
Sourceimpl TryFrom<i8> for LootMethod
impl TryFrom<i8> for LootMethod
Sourceimpl TryFrom<u16> for LootMethod
impl TryFrom<u16> for LootMethod
Sourceimpl TryFrom<u32> for LootMethod
impl TryFrom<u32> for LootMethod
Sourceimpl TryFrom<u64> for LootMethod
impl TryFrom<u64> for LootMethod
Sourceimpl TryFrom<u8> for LootMethod
impl TryFrom<u8> for LootMethod
Sourceimpl TryFrom<usize> for LootMethod
impl TryFrom<usize> for LootMethod
impl Copy for LootMethod
impl Eq for LootMethod
impl StructuralPartialEq for LootMethod