pub enum RaidGroupError {
Required,
Full,
}Available on crate feature
vanilla and (crate features shared or vanilla or tbc or wrath) only.Expand description
Auto generated from the original wowm in file wow_message_parser/wowm/world/social/smsg_raid_group_only.wowm:3:
enum RaidGroupError : u32 {
REQUIRED = 1;
FULL = 2;
}Variants
Implementations
Sourceimpl RaidGroupError
impl RaidGroupError
pub const fn as_test_case_value(&self) -> &'static str
Available on crate feature
print-testcase only.Trait Implementations
Sourceimpl Clone for RaidGroupError
impl Clone for RaidGroupError
Sourcefn clone(&self) -> RaidGroupError
fn clone(&self) -> RaidGroupError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RaidGroupError
impl Debug for RaidGroupError
Sourceimpl Default for RaidGroupError
impl Default for RaidGroupError
Sourceimpl<'de> Deserialize<'de> for RaidGroupError
impl<'de> Deserialize<'de> for RaidGroupError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for RaidGroupError
impl Display for RaidGroupError
Sourceimpl Hash for RaidGroupError
impl Hash for RaidGroupError
Sourceimpl Ord for RaidGroupError
impl Ord for RaidGroupError
Sourcefn cmp(&self, other: &RaidGroupError) -> Ordering
fn cmp(&self, other: &RaidGroupError) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RaidGroupError
impl PartialEq for RaidGroupError
Sourceimpl PartialOrd for RaidGroupError
impl PartialOrd for RaidGroupError
Sourceimpl Serialize for RaidGroupError
impl Serialize for RaidGroupError
Sourceimpl TryFrom<i16> for RaidGroupError
impl TryFrom<i16> for RaidGroupError
Sourceimpl TryFrom<i32> for RaidGroupError
impl TryFrom<i32> for RaidGroupError
Sourceimpl TryFrom<i64> for RaidGroupError
impl TryFrom<i64> for RaidGroupError
Sourceimpl TryFrom<i8> for RaidGroupError
impl TryFrom<i8> for RaidGroupError
Sourceimpl TryFrom<u16> for RaidGroupError
impl TryFrom<u16> for RaidGroupError
Sourceimpl TryFrom<u32> for RaidGroupError
impl TryFrom<u32> for RaidGroupError
Sourceimpl TryFrom<u64> for RaidGroupError
impl TryFrom<u64> for RaidGroupError
Sourceimpl TryFrom<u8> for RaidGroupError
impl TryFrom<u8> for RaidGroupError
Sourceimpl TryFrom<usize> for RaidGroupError
impl TryFrom<usize> for RaidGroupError
impl Copy for RaidGroupError
impl Eq for RaidGroupError
impl StructuralPartialEq for RaidGroupError