Struct AttributesEx1

pub struct AttributesEx1 { /* private fields */ }
Available on crate feature vanilla only.
This type is not sent over the network, but is used in the game in another way.

Auto generated from the original wowm in file wow_message_parser/wowm/world/external/external_spell_1_12.wowm:42:

flag AttributesEx1 : u32 {
    NONE = 0x00;
    DISMISS_PET_FIRST = 0x00000001;
    USE_ALL_MANA = 0x00000002;
    IS_CHANNELED = 0x00000004;
    NO_REDIRECTION = 0x00000008;
    NO_SKILL_INCREASE = 0x00000010;
    ALLOW_WHILE_STEALTHED = 0x00000020;
    IS_SELF_CHANNELED = 0x00000040;
    NO_REFLECTION = 0x00000080;
    ONLY_PEACEFUL_TARGETS = 0x00000100;
    INITIATES_COMBAT_ENABLES_AUTO_ATTACK = 0x00000200;
    NO_THREAT = 0x00000400;
    AURA_UNIQUE = 0x00000800;
    FAILURE_BREAKS_STEALTH = 0x00001000;
    TOGGLE_FARSIGHT = 0x00002000;
    TRACK_TARGET_IN_CHANNEL = 0x00004000;
    IMMUNITY_PURGES_EFFECT = 0x00008000;
    IMMUNITY_TO_HOSTILE_AND_FRIENDLY_EFFECTS = 0x00010000;
    NO_AUTOCAST_AI = 0x00020000;
    PREVENTS_ANIM = 0x00040000;
    EXCLUDE_CASTER = 0x00080000;
    FINISHING_MOVE_DAMAGE = 0x00100000;
    THREAT_ONLY_ON_MISS = 0x00200000;
    FINISHING_MOVE_DURATION = 0x00400000;
    UNK23 = 0x00800000;
    SPECIAL_SKILLUP = 0x01000000;
    AURA_STAYS_AFTER_COMBAT = 0x02000000;
    REQUIRE_ALL_TARGETS = 0x04000000;
    DISCOUNT_POWER_ON_MISS = 0x08000000;
    NO_AURA_ICON = 0x10000000;
    NAME_IN_CHANNEL_BAR = 0x20000000;
    COMBO_ON_BLOCK = 0x40000000;
    CAST_WHEN_LEARNED = 0x80000000;
}

Implementations

Source

impl AttributesEx1

pub fn as_test_case_value(&self) -> String

Available on crate feature print-testcase only.
Source

impl AttributesEx1

pub const NONE: u32 = 0u32

pub const DISMISS_PET_FIRST: u32 = 1u32

pub const USE_ALL_MANA: u32 = 2u32

pub const IS_CHANNELED: u32 = 4u32

pub const NO_REDIRECTION: u32 = 8u32

pub const NO_SKILL_INCREASE: u32 = 16u32

pub const ALLOW_WHILE_STEALTHED: u32 = 32u32

pub const IS_SELF_CHANNELED: u32 = 64u32

pub const NO_REFLECTION: u32 = 128u32

pub const ONLY_PEACEFUL_TARGETS: u32 = 256u32

pub const INITIATES_COMBAT_ENABLES_AUTO_ATTACK: u32 = 512u32

pub const NO_THREAT: u32 = 1_024u32

pub const AURA_UNIQUE: u32 = 2_048u32

pub const FAILURE_BREAKS_STEALTH: u32 = 4_096u32

pub const TOGGLE_FARSIGHT: u32 = 8_192u32

pub const TRACK_TARGET_IN_CHANNEL: u32 = 16_384u32

pub const IMMUNITY_PURGES_EFFECT: u32 = 32_768u32

pub const IMMUNITY_TO_HOSTILE_AND_FRIENDLY_EFFECTS: u32 = 65_536u32

pub const NO_AUTOCAST_AI: u32 = 131_072u32

pub const PREVENTS_ANIM: u32 = 262_144u32

pub const EXCLUDE_CASTER: u32 = 524_288u32

pub const FINISHING_MOVE_DAMAGE: u32 = 1_048_576u32

pub const THREAT_ONLY_ON_MISS: u32 = 2_097_152u32

pub const FINISHING_MOVE_DURATION: u32 = 4_194_304u32

pub const UNK23: u32 = 8_388_608u32

pub const SPECIAL_SKILLUP: u32 = 16_777_216u32

pub const AURA_STAYS_AFTER_COMBAT: u32 = 33_554_432u32

pub const REQUIRE_ALL_TARGETS: u32 = 67_108_864u32

pub const DISCOUNT_POWER_ON_MISS: u32 = 134_217_728u32

pub const NO_AURA_ICON: u32 = 268_435_456u32

pub const NAME_IN_CHANNEL_BAR: u32 = 536_870_912u32

pub const COMBO_ON_BLOCK: u32 = 1_073_741_824u32

pub const CAST_WHEN_LEARNED: u32 = 2_147_483_648u32

pub const fn new(inner: u32) -> Self

pub const fn empty() -> Self

pub const fn is_empty(&self) -> bool

pub const fn all() -> Self

pub const fn is_dismiss_pet_first(&self) -> bool

pub const fn new_dismiss_pet_first() -> Self

pub fn set_dismiss_pet_first(&mut self) -> Self

pub fn clear_dismiss_pet_first(&mut self) -> Self

pub const fn is_use_all_mana(&self) -> bool

pub const fn new_use_all_mana() -> Self

pub fn set_use_all_mana(&mut self) -> Self

pub fn clear_use_all_mana(&mut self) -> Self

pub const fn is_is_channeled(&self) -> bool

pub const fn new_is_channeled() -> Self

pub fn set_is_channeled(&mut self) -> Self

pub fn clear_is_channeled(&mut self) -> Self

pub const fn is_no_redirection(&self) -> bool

pub const fn new_no_redirection() -> Self

pub fn set_no_redirection(&mut self) -> Self

pub fn clear_no_redirection(&mut self) -> Self

pub const fn is_no_skill_increase(&self) -> bool

pub const fn new_no_skill_increase() -> Self

pub fn set_no_skill_increase(&mut self) -> Self

pub fn clear_no_skill_increase(&mut self) -> Self

pub const fn is_allow_while_stealthed(&self) -> bool

pub const fn new_allow_while_stealthed() -> Self

pub fn set_allow_while_stealthed(&mut self) -> Self

pub fn clear_allow_while_stealthed(&mut self) -> Self

pub const fn is_is_self_channeled(&self) -> bool

pub const fn new_is_self_channeled() -> Self

pub fn set_is_self_channeled(&mut self) -> Self

pub fn clear_is_self_channeled(&mut self) -> Self

pub const fn is_no_reflection(&self) -> bool

pub const fn new_no_reflection() -> Self

pub fn set_no_reflection(&mut self) -> Self

pub fn clear_no_reflection(&mut self) -> Self

pub const fn is_only_peaceful_targets(&self) -> bool

pub const fn new_only_peaceful_targets() -> Self

pub fn set_only_peaceful_targets(&mut self) -> Self

pub fn clear_only_peaceful_targets(&mut self) -> Self

pub const fn is_initiates_combat_enables_auto_attack(&self) -> bool

pub const fn new_initiates_combat_enables_auto_attack() -> Self

pub fn set_initiates_combat_enables_auto_attack(&mut self) -> Self

pub fn clear_initiates_combat_enables_auto_attack(&mut self) -> Self

pub const fn is_no_threat(&self) -> bool

pub const fn new_no_threat() -> Self

pub fn set_no_threat(&mut self) -> Self

pub fn clear_no_threat(&mut self) -> Self

pub const fn is_aura_unique(&self) -> bool

pub const fn new_aura_unique() -> Self

pub fn set_aura_unique(&mut self) -> Self

pub fn clear_aura_unique(&mut self) -> Self

pub const fn is_failure_breaks_stealth(&self) -> bool

pub const fn new_failure_breaks_stealth() -> Self

pub fn set_failure_breaks_stealth(&mut self) -> Self

pub fn clear_failure_breaks_stealth(&mut self) -> Self

pub const fn is_toggle_farsight(&self) -> bool

pub const fn new_toggle_farsight() -> Self

pub fn set_toggle_farsight(&mut self) -> Self

pub fn clear_toggle_farsight(&mut self) -> Self

pub const fn is_track_target_in_channel(&self) -> bool

pub const fn new_track_target_in_channel() -> Self

pub fn set_track_target_in_channel(&mut self) -> Self

pub fn clear_track_target_in_channel(&mut self) -> Self

pub const fn is_immunity_purges_effect(&self) -> bool

pub const fn new_immunity_purges_effect() -> Self

pub fn set_immunity_purges_effect(&mut self) -> Self

pub fn clear_immunity_purges_effect(&mut self) -> Self

pub const fn is_immunity_to_hostile_and_friendly_effects(&self) -> bool

pub const fn new_immunity_to_hostile_and_friendly_effects() -> Self

pub fn set_immunity_to_hostile_and_friendly_effects(&mut self) -> Self

pub fn clear_immunity_to_hostile_and_friendly_effects(&mut self) -> Self

pub const fn is_no_autocast_ai(&self) -> bool

pub const fn new_no_autocast_ai() -> Self

pub fn set_no_autocast_ai(&mut self) -> Self

pub fn clear_no_autocast_ai(&mut self) -> Self

pub const fn is_prevents_anim(&self) -> bool

pub const fn new_prevents_anim() -> Self

pub fn set_prevents_anim(&mut self) -> Self

pub fn clear_prevents_anim(&mut self) -> Self

pub const fn is_exclude_caster(&self) -> bool

pub const fn new_exclude_caster() -> Self

pub fn set_exclude_caster(&mut self) -> Self

pub fn clear_exclude_caster(&mut self) -> Self

pub const fn is_finishing_move_damage(&self) -> bool

pub const fn new_finishing_move_damage() -> Self

pub fn set_finishing_move_damage(&mut self) -> Self

pub fn clear_finishing_move_damage(&mut self) -> Self

pub const fn is_threat_only_on_miss(&self) -> bool

pub const fn new_threat_only_on_miss() -> Self

pub fn set_threat_only_on_miss(&mut self) -> Self

pub fn clear_threat_only_on_miss(&mut self) -> Self

pub const fn is_finishing_move_duration(&self) -> bool

pub const fn new_finishing_move_duration() -> Self

pub fn set_finishing_move_duration(&mut self) -> Self

pub fn clear_finishing_move_duration(&mut self) -> Self

pub const fn is_unk23(&self) -> bool

pub const fn new_unk23() -> Self

pub fn set_unk23(&mut self) -> Self

pub fn clear_unk23(&mut self) -> Self

pub const fn is_special_skillup(&self) -> bool

pub const fn new_special_skillup() -> Self

pub fn set_special_skillup(&mut self) -> Self

pub fn clear_special_skillup(&mut self) -> Self

pub const fn is_aura_stays_after_combat(&self) -> bool

pub const fn new_aura_stays_after_combat() -> Self

pub fn set_aura_stays_after_combat(&mut self) -> Self

pub fn clear_aura_stays_after_combat(&mut self) -> Self

pub const fn is_require_all_targets(&self) -> bool

pub const fn new_require_all_targets() -> Self

pub fn set_require_all_targets(&mut self) -> Self

pub fn clear_require_all_targets(&mut self) -> Self

pub const fn is_discount_power_on_miss(&self) -> bool

pub const fn new_discount_power_on_miss() -> Self

pub fn set_discount_power_on_miss(&mut self) -> Self

pub fn clear_discount_power_on_miss(&mut self) -> Self

pub const fn is_no_aura_icon(&self) -> bool

pub const fn new_no_aura_icon() -> Self

pub fn set_no_aura_icon(&mut self) -> Self

pub fn clear_no_aura_icon(&mut self) -> Self

pub const fn is_name_in_channel_bar(&self) -> bool

pub const fn new_name_in_channel_bar() -> Self

pub fn set_name_in_channel_bar(&mut self) -> Self

pub fn clear_name_in_channel_bar(&mut self) -> Self

pub const fn is_combo_on_block(&self) -> bool

pub const fn new_combo_on_block() -> Self

pub fn set_combo_on_block(&mut self) -> Self

pub fn clear_combo_on_block(&mut self) -> Self

pub const fn is_cast_when_learned(&self) -> bool

pub const fn new_cast_when_learned() -> Self

pub fn set_cast_when_learned(&mut self) -> Self

pub fn clear_cast_when_learned(&mut self) -> Self

pub const fn as_int(&self) -> u32