Struct EmoteFlags

pub struct EmoteFlags { /* private fields */ }
Available on crate feature vanilla only.
Used in Emotes.dbc.

This type is not sent over the network, but is used in the game in another way.

Auto generated from the original wowm in file wow_message_parser/wowm/world/external/emote_flags.wowm:2:

flag EmoteFlags : u8 {
    TALK = 0x08;
    QUESTION = 0x10;
    EXCLAMATION = 0x20;
    SHOUT = 0x40;
    LAUGH = 0x80;
}

Implementations

Source

impl EmoteFlags

pub fn as_test_case_value(&self) -> String

Available on crate feature print-testcase only.
Source

impl EmoteFlags

pub const TALK: u8 = 8u8

pub const QUESTION: u8 = 16u8

pub const EXCLAMATION: u8 = 32u8

pub const SHOUT: u8 = 64u8

pub const LAUGH: u8 = 128u8

pub const fn new(inner: u8) -> Self

pub const fn empty() -> Self

pub const fn is_empty(&self) -> bool

pub const fn all() -> Self

pub const fn is_talk(&self) -> bool

pub const fn new_talk() -> Self

pub fn set_talk(&mut self) -> Self

pub fn clear_talk(&mut self) -> Self

pub const fn is_question(&self) -> bool

pub const fn new_question() -> Self

pub fn set_question(&mut self) -> Self

pub fn clear_question(&mut self) -> Self

pub const fn is_exclamation(&self) -> bool

pub const fn new_exclamation() -> Self

pub fn set_exclamation(&mut self) -> Self

pub fn clear_exclamation(&mut self) -> Self

pub const fn is_shout(&self) -> bool

pub const fn new_shout() -> Self

pub fn set_shout(&mut self) -> Self

pub fn clear_shout(&mut self) -> Self

pub const fn is_laugh(&self) -> bool

pub const fn new_laugh() -> Self

pub fn set_laugh(&mut self) -> Self

pub fn clear_laugh(&mut self) -> Self

pub const fn as_int(&self) -> u8