pub enum AuctionCommandResultTwo {
Ok,
ErrInventory,
ErrDatabase,
ErrNotEnoughMoney,
ErrItemNotFound,
ErrHigherBid,
ErrBidIncrement,
ErrBidOwn,
ErrRestrictedAccount,
}Available on crate feature
wrath and (crate features shared or vanilla or tbc or wrath) only.Expand description
Auto generated from the original wowm in file wow_message_parser/wowm/world/auction/smsg/smsg_auction_command_result.wowm:64:
enum AuctionCommandResultTwo : u32 {
OK = 0;
ERR_INVENTORY = 1;
ERR_DATABASE = 2;
ERR_NOT_ENOUGH_MONEY = 3;
ERR_ITEM_NOT_FOUND = 4;
ERR_HIGHER_BID = 5;
ERR_BID_INCREMENT = 7;
ERR_BID_OWN = 10;
ERR_RESTRICTED_ACCOUNT = 13;
}Variants
Ok
depends on enum AuctionAction
ErrInventory
depends on enum InventoryChangeResult
ErrDatabase
ERR_AUCTION_DATABASE_ERROR (default)
ErrNotEnoughMoney
ERR_NOT_ENOUGH_MONEY
ErrItemNotFound
ERR_ITEM_NOT_FOUND
ErrHigherBid
ERR_AUCTION_HIGHER_BID
ErrBidIncrement
ERR_AUCTION_BID_INCREMENT
ErrBidOwn
ERR_AUCTION_BID_OWN
ErrRestrictedAccount
ERR_RESTRICTED_ACCOUNT
Implementations
Sourceimpl AuctionCommandResultTwo
impl AuctionCommandResultTwo
pub const fn as_test_case_value(&self) -> &'static str
Available on crate feature
print-testcase only.Trait Implementations
Sourceimpl Clone for AuctionCommandResultTwo
impl Clone for AuctionCommandResultTwo
Sourcefn clone(&self) -> AuctionCommandResultTwo
fn clone(&self) -> AuctionCommandResultTwo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuctionCommandResultTwo
impl Debug for AuctionCommandResultTwo
Sourceimpl Default for AuctionCommandResultTwo
impl Default for AuctionCommandResultTwo
Sourceimpl<'de> Deserialize<'de> for AuctionCommandResultTwo
impl<'de> Deserialize<'de> for AuctionCommandResultTwo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for AuctionCommandResultTwo
impl Display for AuctionCommandResultTwo
Sourceimpl Hash for AuctionCommandResultTwo
impl Hash for AuctionCommandResultTwo
Sourceimpl Ord for AuctionCommandResultTwo
impl Ord for AuctionCommandResultTwo
Sourcefn cmp(&self, other: &AuctionCommandResultTwo) -> Ordering
fn cmp(&self, other: &AuctionCommandResultTwo) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AuctionCommandResultTwo
impl PartialEq for AuctionCommandResultTwo
Sourceimpl PartialOrd for AuctionCommandResultTwo
impl PartialOrd for AuctionCommandResultTwo
Sourceimpl Serialize for AuctionCommandResultTwo
impl Serialize for AuctionCommandResultTwo
Sourceimpl TryFrom<i16> for AuctionCommandResultTwo
impl TryFrom<i16> for AuctionCommandResultTwo
Sourceimpl TryFrom<i32> for AuctionCommandResultTwo
impl TryFrom<i32> for AuctionCommandResultTwo
Sourceimpl TryFrom<i64> for AuctionCommandResultTwo
impl TryFrom<i64> for AuctionCommandResultTwo
Sourceimpl TryFrom<i8> for AuctionCommandResultTwo
impl TryFrom<i8> for AuctionCommandResultTwo
Sourceimpl TryFrom<u16> for AuctionCommandResultTwo
impl TryFrom<u16> for AuctionCommandResultTwo
Sourceimpl TryFrom<u32> for AuctionCommandResultTwo
impl TryFrom<u32> for AuctionCommandResultTwo
Sourceimpl TryFrom<u64> for AuctionCommandResultTwo
impl TryFrom<u64> for AuctionCommandResultTwo
Sourceimpl TryFrom<u8> for AuctionCommandResultTwo
impl TryFrom<u8> for AuctionCommandResultTwo
Sourceimpl TryFrom<usize> for AuctionCommandResultTwo
impl TryFrom<usize> for AuctionCommandResultTwo
impl Copy for AuctionCommandResultTwo
impl Eq for AuctionCommandResultTwo
impl StructuralPartialEq for AuctionCommandResultTwo