Enum ChatNotify

pub enum ChatNotify {
Show 36 variants JoinedNotice, LeftNotice, YouJoinedNotice, YouLeftNotice, WrongPasswordNotice, NotMemberNotice, NotModeratorNotice, PasswordChangedNotice, OwnerChangedNotice, PlayerNotFoundNotice, NotOwnerNotice, ChannelOwnerNotice, ModeChangeNotice, AnnouncementsOnNotice, AnnouncementsOffNotice, ModerationOnNotice, ModerationOffNotice, MutedNotice, PlayerKickedNotice, BannedNotice, PlayerBannedNotice, PlayerUnbannedNotice, PlayerNotBannedNotice, PlayerAlreadyMemberNotice, InviteNotice, InviteWrongFactionNotice, WrongFactionNotice, InvalidNameNotice, NotModeratedNotice, PlayerInvitedNotice, PlayerInviteBannedNotice, ThrottledNotice, NotInAreaNotice, NotInLfgNotice, VoiceOnNotice, VoiceOffNotice,
}
Available on crate feature wrath and (crate features shared or tbc or wrath) only.
Auto generated from the original wowm in file wow_message_parser/wowm/world/chat/smsg_channel_notify.wowm:76:

enum ChatNotify : u8 {
    JOINED_NOTICE = 0x00;
    LEFT_NOTICE = 0x01;
    YOU_JOINED_NOTICE = 0x02;
    YOU_LEFT_NOTICE = 0x03;
    WRONG_PASSWORD_NOTICE = 0x04;
    NOT_MEMBER_NOTICE = 0x05;
    NOT_MODERATOR_NOTICE = 0x06;
    PASSWORD_CHANGED_NOTICE = 0x07;
    OWNER_CHANGED_NOTICE = 0x08;
    PLAYER_NOT_FOUND_NOTICE = 0x09;
    NOT_OWNER_NOTICE = 0x0A;
    CHANNEL_OWNER_NOTICE = 0x0B;
    MODE_CHANGE_NOTICE = 0x0C;
    ANNOUNCEMENTS_ON_NOTICE = 0x0D;
    ANNOUNCEMENTS_OFF_NOTICE = 0x0E;
    MODERATION_ON_NOTICE = 0x0F;
    MODERATION_OFF_NOTICE = 0x10;
    MUTED_NOTICE = 0x11;
    PLAYER_KICKED_NOTICE = 0x12;
    BANNED_NOTICE = 0x13;
    PLAYER_BANNED_NOTICE = 0x14;
    PLAYER_UNBANNED_NOTICE = 0x15;
    PLAYER_NOT_BANNED_NOTICE = 0x16;
    PLAYER_ALREADY_MEMBER_NOTICE = 0x17;
    INVITE_NOTICE = 0x18;
    INVITE_WRONG_FACTION_NOTICE = 0x19;
    WRONG_FACTION_NOTICE = 0x1A;
    INVALID_NAME_NOTICE = 0x1B;
    NOT_MODERATED_NOTICE = 0x1C;
    PLAYER_INVITED_NOTICE = 0x1D;
    PLAYER_INVITE_BANNED_NOTICE = 0x1E;
    THROTTLED_NOTICE = 0x1F;
    NOT_IN_AREA_NOTICE = 0x20;
    NOT_IN_LFG_NOTICE = 0x21;
    VOICE_ON_NOTICE = 0x22;
    VOICE_OFF_NOTICE = 0x23;
}

Variants



JoinedNotice

%s joined channel.



LeftNotice

%s left channel.



YouJoinedNotice

Joined Channel: %s – You joined



YouLeftNotice

Left Channel: %s – You left



WrongPasswordNotice

Wrong password for %s.



NotMemberNotice

Not on channel %s.



NotModeratorNotice

Not a moderator of %s.



PasswordChangedNotice

%s Password changed by %s.



OwnerChangedNotice

%s Owner changed to %s.



PlayerNotFoundNotice

%s Player %s was not found.



NotOwnerNotice

%s You are not the channel owner.



ChannelOwnerNotice

%s Channel owner is %s.



ModeChangeNotice



AnnouncementsOnNotice

%s Channel announcements enabled by %s.



AnnouncementsOffNotice

%s Channel announcements disabled by %s.



ModerationOnNotice

%s Channel moderation enabled by %s.



ModerationOffNotice

%s Channel moderation disabled by %s.



MutedNotice

%s You do not have permission to speak.



PlayerKickedNotice

%s Player %s kicked by %s.



BannedNotice

%s You are banned from that channel.



PlayerBannedNotice

%s Player %s banned by %s.



PlayerUnbannedNotice

%s Player %s unbanned by %s.



PlayerNotBannedNotice

%s Player %s is not banned.



PlayerAlreadyMemberNotice

%s Player %s is already on the channel.



InviteNotice

%2$s has invited you to join the channel ‘%1$s’.



InviteWrongFactionNotice

Target is in the wrong alliance for %s.



WrongFactionNotice

Wrong alliance for %s.



InvalidNameNotice

Invalid channel name



NotModeratedNotice

%s is not moderated



PlayerInvitedNotice

%s You invited %s to join the channel



PlayerInviteBannedNotice

%s %s has been banned.



ThrottledNotice

%s The number of messages that can be sent to this channel is limited, please wait to send another message.



NotInAreaNotice

%s You are not in the correct area for this channel. – The user is trying to send a chat to a zone specific channel, and they’re not physically in that zone.



NotInLfgNotice

%s You must be queued in looking for group before joining this channel. – The user must be in the looking for group system to join LFG chat channels.



VoiceOnNotice

%s Channel voice enabled by %s.



VoiceOffNotice

%s Channel voice disabled by %s.

Implementations

Source

impl ChatNotify

pub const fn as_int(&self) -> u8

pub const fn variants() -> [Self; 36]

pub const fn from_int(value: u8) -> Result<Self, EnumError>

Source

impl ChatNotify

pub const fn as_test_case_value(&self) -> &'static str

Available on crate feature print-testcase only.