Enum SizeClass

pub enum SizeClass {
    None,
    Small,
    Medium,
    Large,
    Giant,
    Colossal,
}
Available on crate feature wrath and (crate features shared or vanilla or tbc or wrath) only.
Used in the CreatureDisplayInfo.dbc, CreatureModelData.dbc and DeathThudLookups.dbc.

This type is not sent over the network, but is used in the game in another way.

Auto generated from the original wowm in file wow_message_parser/wowm/world/external/size_class.wowm:2:

enum SizeClass : i8 {
    NONE = -1;
    SMALL = 0;
    MEDIUM = 1;
    LARGE = 2;
    GIANT = 3;
    COLOSSAL = 4;
}

Variants



None



Small



Medium



Large



Giant



Colossal

Implementations

Source

impl SizeClass

pub const fn as_int(&self) -> i8

pub const fn variants() -> [Self; 6]

pub const fn from_int(value: i8) -> Result<Self, EnumError>

Source

impl SizeClass

pub const fn as_test_case_value(&self) -> &'static str

Available on crate feature print-testcase only.