pub struct ChannelFlags { /* private fields */ }Available on crate feature
vanilla and (crate features shared or vanilla or tbc or wrath) only.Expand description
Auto generated from the original wowm in file wow_message_parser/wowm/world/chat/smsg_channel_list.wowm:3:
flag ChannelFlags : u8 {
NONE = 0x00;
CUSTOM = 0x01;
TRADE = 0x04;
NOT_LFG = 0x08;
GENERAL = 0x10;
CITY = 0x20;
LFG = 0x40;
VOICE = 0x80;
}Implementations
Sourceimpl ChannelFlags
impl ChannelFlags
pub fn as_test_case_value(&self) -> String
Available on crate feature
print-testcase only.Sourceimpl ChannelFlags
impl ChannelFlags
pub const NONE: u8 = 0u8
pub const CUSTOM: u8 = 1u8
pub const TRADE: u8 = 4u8
pub const NOT_LFG: u8 = 8u8
pub const GENERAL: u8 = 16u8
pub const CITY: u8 = 32u8
pub const LFG: u8 = 64u8
pub const VOICE: u8 = 128u8
pub const fn new(inner: u8) -> Self
pub const fn empty() -> Self
pub const fn is_empty(&self) -> bool
pub const fn all() -> Self
pub const fn is_custom(&self) -> bool
pub const fn new_custom() -> Self
pub fn set_custom(&mut self) -> Self
pub fn clear_custom(&mut self) -> Self
pub const fn is_trade(&self) -> bool
pub const fn new_trade() -> Self
pub fn set_trade(&mut self) -> Self
pub fn clear_trade(&mut self) -> Self
pub const fn is_not_lfg(&self) -> bool
pub const fn new_not_lfg() -> Self
pub fn set_not_lfg(&mut self) -> Self
pub fn clear_not_lfg(&mut self) -> Self
pub const fn is_general(&self) -> bool
pub const fn new_general() -> Self
pub fn set_general(&mut self) -> Self
pub fn clear_general(&mut self) -> Self
pub const fn is_city(&self) -> bool
pub const fn new_city() -> Self
pub fn set_city(&mut self) -> Self
pub fn clear_city(&mut self) -> Self
pub const fn is_lfg(&self) -> bool
pub const fn new_lfg() -> Self
pub fn set_lfg(&mut self) -> Self
pub fn clear_lfg(&mut self) -> Self
pub const fn is_voice(&self) -> bool
pub const fn new_voice() -> Self
pub fn set_voice(&mut self) -> Self
pub fn clear_voice(&mut self) -> Self
pub const fn as_int(&self) -> u8