pub enum SizeClass {
None,
Small,
Medium,
Large,
Giant,
Colossal,
}Available on crate feature
wrath and (crate features shared or vanilla or tbc or wrath) only.Expand description
Used in the CreatureDisplayInfo.dbc, CreatureModelData.dbc and DeathThudLookups.dbc.
This type is not sent over the network, but is used in the game in another way.
Auto generated from the original wowm in file wow_message_parser/wowm/world/external/size_class.wowm:2:
enum SizeClass : i8 {
NONE = -1;
SMALL = 0;
MEDIUM = 1;
LARGE = 2;
GIANT = 3;
COLOSSAL = 4;
}Variants
Implementations